#!/bin/bash

VOLUME=/
IMACUSE_OC=NO

DID=`/usr/sbin/chroot $VOLUME /usr/sbin/system_profiler SPDisplaysDataType | fgrep "Device ID" | awk '{print $3}'`

case $DID in
    # OpenCore: K610M
    0x12b9)
    IMACUSE_OC=YES
    echo "NVIDIA K610M found, assume use of OC"
    ;;
    # OpenCore: K1100M
    0x0ff6)
    IMACUSE_OC=YES
    echo "NVIDIA K1100M found, assume use of OC"
    ;;
    # OpenCore: K2100M
    0x11fc)
    IMACUSE_OC=YES
    echo "NVIDIA K2100M found, assume use of OC"
    ;;
    # OpenCore; AMD Baffin cards
    0x67e8)
    echo "AMD Polaris WX4130/WX4150 found, assume use of OC"
    IMACUSE_OC=YES
    ;;
    0x67e0|0x67ef)
    echo "AMD Polaris WX4170 found, assume use of OC"
    IMACUSE_OC=YES
    ;;
    0x67c0)
    echo "AMD Polaris WX7100 found, assume use of OC"
    IMACUSE_OC=YES
    ;;
    0x67df)
    echo "AMD Polaris RX480 found, assume use of OC"
    IMACUSE_OC=YES
    ;;
    0x67??)
    echo "unknow AMD Polaris found, assume use of OC, device ID" $DID
    IMACUSE_OC=YES
    ;;
    # NVIDIA witout OpenCore
    0x1198)
    echo "NVIDIA 880M found"
    IMACUSE_OC=NO
    ;;
    0x1199)
    echo "NVIDIA 870M found"
    IMACUSE_OC=NO
    ;;
    0x119A)
    echo "NVIDIA 860M found"
    IMACUSE_OC=NO
    ;;
    0x119f)
    echo "NVIDIA 780M found"
    IMACUSE_OC=NO
    ;;
    0x11e0)
    echo "NVIDIA 770M found"
    IMACUSE_OC=NO
    ;;
    0x11e1)
    echo "NVIDIA 765M found"
    IMACUSE_OC=NO
    ;;
    0x11b8)
    echo "NVIDIA K5100M found"
    IMACUSE_OC=NO
    ;;
    0x11b7)
    echo "NVIDIA K4100M found"
    IMACUSE_OC=NO
    ;;
    0x11b6)
    echo "NVIDIA K3100M found"
    IMACUSE_OC=NO
    ;;
    0x11bc)
    echo "NVIDIA K5000M found"
    IMACUSE_OC=NO
    ;;
    0x11bd)
    echo "NVIDIA K4000M found"
    IMACUSE_OC=NO
    ;;
    0x11be)
    echo "NVIDIA K3000M found"
    IMACUSE_OC=NO
    ;;
    0x0ffb)
    echo "NVIDIA K2000M found"
    IMACUSE_OC=NO
    ;;
    0x0ffc)
    echo "NVIDIA K1000M found"
    IMACUSE_OC=NO
    ;;
    *)
    echo "Unknown GPU model. This may be a patcher bug, or a the original Apple iMac AMD GPU which is"
    echo "not really supported by Big Sur and will run without any graphics acceleration."
    IMACUSE_OC=NO
    ;;
esac

case $DID in
    # OpenCore: K610M, K1100M, K2100M
    0x12b9 | 0x0ff6 | 0x11fc)
    IMACUSE_OC=YES
    echo "NVIDIA K610M, K1100M, K2100M found, assume use of OC, device ID: " $DID
    ;;
    # OpenCore; AMD Baffin cards
    0x67e8 | 0x67e0 | 0x67c0 | 0x67df | 0x67ef)
    echo "AMD Polaris WX4130/WX4150/WX4170/WX7100/RX480 found, assume use of OC, device ID: " $DID
    IMACUSE_OC=YES
    ;;
    0x67??)
    echo "unknow AMD Polaris found, assume use of OC, device ID: " $DID
    IMACUSE_OC=YES
    ;;
    # NVIDIA witout OpenCore
    0x1198 | 0x1199 | 0x119A | 0x119f | 0x11e0 | 0x11e1 | 0x11b8 | 0x11b7 | 0x11b6 | 0x11bc | 0x11bd | 0x11be |0x0ffb | 0x0ffc)
    echo "NVIDIA Kepler Kx100M, Kx000M, GTX8xx, GTX7xx Card found"
    IMACUSE_OC=NO
    ;;
    *)
    echo "Unknown GPU model. This may be a patcher bug, or the original Apple iMac ATI GPU which"
    echo "is not really usable with Big Sur and will run without any graphics acceleration."
    IMACUSE_OC=NO
    ;;
esac

echo "IMACUSE_OC == " $IMACUSE_OC


